@@ -1,11 +1,11 @@
 import inspect
 import os
 from contextvars import copy_context
-from typing import Mapping, Optional, Union
+from typing import Mapping, Optional, Union,Dict
 
 from argo_workflow_tools.dsl import building_mode_context, workflow_template_collector
 from argo_workflow_tools.dsl.condition import BinaryOp, UnaryOp
-from argo_workflow_tools.dsl.dag_task import DAGReference, NodeReference, TaskReference
+from argo_workflow_tools.dsl.dag_task import DAGReference, NodeReference, TaskReference, WorkflowTemplateReference
 from argo_workflow_tools.dsl.node import DAGNode
 from argo_workflow_tools.dsl.input_definition import InputDefinition, SourceType
 from argo_workflow_tools.dsl.node_properties import (
@@ -26,7 +26,7 @@ from argo_workflow_tools.models.io.argoproj.workflow import v1alpha1 as argo
 
 
 def _create_task_script(
-        func_obj: TaskReference, parameters: dict[str, argo.Parameter]
+        func_obj: TaskReference, parameters: Dict[str, argo.Parameter]
 ) -> str:
     """
     generates a runnable script out of a task function, adding input and output boilerplate
@@ -195,6 +195,16 @@ def _build_dag_task(dag_task: NodeReference) -> argo.DagTask:
             when=build_condition(dag_task.conditions),
         )
         return task
+    elif isinstance(dag_task, WorkflowTemplateReference):
+        task = argo.DagTask(
+            name=dag_task.id,
+            templateRef=argo.TemplateRef(name=dag_task.workflow_template_name, template=dag_task.name),
+            dependencies=list(dependencies),
+            arguments=get_arguments(arguments),
+            withParam=with_param,
+            when=build_condition(dag_task.conditions),
+        )
+        return task
     else:
         raise AssertionError("only DAG or task nodes are supported")
 
