@@ -43,3 +43,15 @@ class TaskReference(NodeReference):
 
     def __repr__(self):
         return f"TaskReference(name={self.name} id={self.id})"
+
+
+@dataclass
+class WorkflowTemplateReference(NodeReference):
+    """
+    Represents a result referece from a called task
+    """
+    workflow_template_name: str
+    properties: DAGNodeProperties
+
+    def __repr__(self):
+        return f"WorkflowTemplateReference(name={self.name} id={self.id})"
