@@ -3,7 +3,7 @@ from abc import abstractmethod
 from typing import Any, Callable, Dict, Iterable, Mapping, Sequence, cast
 
 from argo_workflow_tools.dsl import building_mode_context as context
-from argo_workflow_tools.dsl.dag_task import DAGReference, TaskReference
+from argo_workflow_tools.dsl.dag_task import DAGReference, TaskReference, WorkflowTemplateReference
 from argo_workflow_tools.dsl.input_definition import InputDefinition, SourceType
 from argo_workflow_tools.dsl.node_properties.dag_node_properties import (
     DAGNodeProperties,
@@ -114,7 +114,7 @@ class Node(object):
                 references=arg[0],
             )
 
-        if isinstance(arg, Sequence) and any([item.is_node_output for item in arg]):
+        if not isinstance(arg, str) and isinstance(arg, Sequence) and any([item.is_node_output for item in arg]):
             raise ValueError(
                 f"Argument '{name}' of type '{type(arg).__name__}' is invalid. it mixes both parameters and node outputs"
             )
@@ -145,12 +145,18 @@ class Node(object):
 
         return {k: self._reduce_fan_in_arguments(k, v) for k, v in arguments.items()}
 
+    @staticmethod
+    def _get_arg(argument_name: str, argument_value: Any) -> InputDefinition:
+        if isinstance(argument_value, InputDefinition):
+            return argument_value
+        return InputDefinition(source_type=SourceType.CONST, value=argument_value ,name=argument_name)
+
     @staticmethod
     def _arguments(arguments: Mapping[str, Any]) -> Mapping[str, InputDefinition]:
         return {
-            argument_name: argument_value
+            argument_name: Node._get_arg(argument_name, argument_value)
             for argument_name, argument_value in arguments.items()
-            if isinstance(argument_value, InputDefinition)
+
         }
 
 
@@ -212,9 +218,6 @@ class DAGNode(Node):
                 for name, parameter_builder in self.properties.outputs.items()
             }
 
-        output = InputDefinition(
-            source_type=SourceType.NODE_OUTPUT, source_node_id=guid, name="result"
-        )
         conditions = collect_conditions()
 
         add_task(
@@ -236,7 +239,6 @@ class DAGNode(Node):
             return outputs
 
 
-
 class TaskNode(Node):
     def __init__(self, func: Callable, properties: TaskNodeProperties):
         """
@@ -313,3 +315,83 @@ class TaskNode(Node):
             return list(outputs.values())[0]
         else:
             return outputs
+
+
+class WorkflowTemplateNode(DAGNode):
+    def __init__(self, func: Callable, name: str, properties: DAGNodeProperties):
+        """
+        reporesents a WorkflowTempalte node in the workflow graph
+        Parameters
+        ----------
+        func : function describing the DAG
+        properties : argo properties for DAG
+        """
+        self.name = name
+        super().__init__(func, properties)
+
+    def __call__(self, *args, **kwargs) -> Any:
+        """
+        call the DAG function, in case we are not in DSL compilation mode, the function will call the function.
+        else the fucntion will return a reference response representing the node response
+        """
+        if not context.dag_building_mode.get():
+            cleaned_kwargs = self._filter_dag_args(kwargs)
+            conditions = collect_conditions()
+            if all([condition.value for condition in conditions]):
+                return self._func(*args, **cleaned_kwargs)
+            else:
+                return None
+
+        guid = sanitize_name(self._func.__name__) + "-" + uuid_short()
+
+        arguments = self._bind_arguments(*args, **kwargs)
+        partitioned_arguments = list(
+            filter(lambda argument: isinstance(argument, InputDefinition) and argument.is_partition, arguments.values())
+        )
+        if len(partitioned_arguments) > 1:
+            raise ValueError(
+                "Nested loops are not allowed in the same DAG, split your loops into nested DAG's instead"
+            )
+
+        if len(self.properties.outputs.items()) == 0:
+            outputs = {"result": InputDefinition(
+                source_type=SourceType.NODE_OUTPUT,
+                source_node_id=guid,
+                name=sanitize_name("result"),
+                references=partitioned_arguments,
+                parameter_builder=self.properties.outputs.get(
+                    "result", DefaultParameterBuilder(None)
+                ),
+            )}
+        else:
+            outputs = {
+                name: InputDefinition(
+                    source_type=SourceType.NODE_OUTPUT,
+                    source_node_id=guid,
+                    name=sanitize_name(name),
+                    references=partitioned_arguments,
+                    parameter_builder=parameter_builder
+                )
+                for name, parameter_builder in self.properties.outputs.items()
+            }
+
+        conditions = collect_conditions()
+
+        add_task(
+            WorkflowTemplateReference(
+                workflow_template_name=self.name,
+                id=guid,
+                name=sanitize_name(self._func.__name__),
+                func=self._func,
+                wait_for=self._get_wait(kwargs),
+                arguments=self._arguments(arguments),
+                outputs=outputs,
+                node=self,
+                properties=self.properties,
+                conditions=conditions,
+            ),
+        )
+        if len(outputs.items()) == 1:
+            return list(outputs.values())[0]
+        else:
+            return outputs
