@@ -1,5 +1,6 @@
 from abc import ABC, abstractmethod
 from collections import Callable
+from typing import Set
 
 
 class ParameterBuilder(ABC):
@@ -7,7 +8,7 @@ class ParameterBuilder(ABC):
         pass
 
     @abstractmethod
-    def imports(self) -> set[str]:
+    def imports(self) -> Set[str]:
         pass
 
     @abstractmethod
